%Calculates the mass flux from the flow to the surge
%K. Kelfoun, Apr. 2021 - UCA / LMV - lmv.uca.fr/kelfoun-karim
%-------------------------------------------------------------------

%"mass" lost by the flow per m, per s. In kg/m/s
flux_mass_ds = coef_a3 * abs(u_dense).^3;

%Thickness lost by the flow, in m/s
dh_perdu_dense = flux_mass_ds / rhoD;

%to ensure that the thickness lost is not thicker than the flow
dh_perdu_dense = min(dh_perdu_dense*dt, h);
FLUX_MASS = FLUX_MASS + dh_perdu_dense; %used to detect where the flux are significant

%Increase of the surge thickness by the mass lost by the flow
dh_gain_surge = dh_perdu_dense * rhoD / rho_mix;
%Increase of the surge "density" (h*density) by the mass lost by the flow
dRw_gain_surge = dh_gain_surge * rho_mix;

%Computes the new thicknesses (h=flow, hw=surge, Rw = hw*surge density rhoS)
h  = h  - dh_perdu_dense;
hw = hw +  dh_gain_surge;
Rw = Rw + dRw_gain_surge;

%New surge density
rhoS(hw>0) = Rw(hw>0)./hw(hw>0);

%momentum conservation
htot= hmx +  (dh_gain_surge(:,1:ncol-1)+dh_gain_surge(:,2:ncol))/2;
uw_xx = ( uw_xx.*hmx + (dh_gain_surge(:,1:ncol-1)+dh_gain_surge(:,2:ncol))/2.*(u_xx * rho_mix / rhoD + uw_xx* (rhoD - rho_mix) / rhoD   ) ) ./ htot;  %Vrifier  * rho_mix / rhoD !
uw_xy = ( uw_xy.*hmx + (dh_gain_surge(:,1:ncol-1)+dh_gain_surge(:,2:ncol))/2.*(u_xy * rho_mix / rhoD + uw_xy* (rhoD - rho_mix) / rhoD   ) ) ./ htot;
uw_xx(htot<1e-3)=0;
uw_xy(htot<1e-3)=0;
htot=hmy+  (dh_gain_surge(1:nrow-1, :)+dh_gain_surge(2:nrow,:))/2;
uw_yx = ( uw_yx.*hmy + (dh_gain_surge(1:nrow-1, :)+dh_gain_surge(2:nrow,:))/2.*(u_yx * rho_mix / rhoD + uw_yx* (rhoD - rho_mix) / rhoD   ) ) ./ htot;
uw_yy = ( uw_yy.*hmy + (dh_gain_surge(1:nrow-1, :)+dh_gain_surge(2:nrow,:))/2.*(u_yy * rho_mix / rhoD + uw_yy* (rhoD - rho_mix) / rhoD   ) ) ./ htot;
uw_yx(htot<1e-3)=0;
uw_yy(htot<1e-3)=0;

